@@ -1,28 +1,18 @@
 # coding: utf-8
-from __future__ import unicode_literals
+from requests import Request
 
-from ..compat import get_bytes
 from .base import AuthBase
 
-try:
-    from typing import TYPE_CHECKING
-
-    if TYPE_CHECKING:
-        from typing import Text
-        from requests import Request
-except ImportError:
-    pass
-
 
 class JWTAuth(AuthBase):
     """ Attaches JSON Web Token Authentication to the given Request object. """
 
     __slots__ = ("token",)
 
-    AUTHORIZATION = get_bytes("Authorization")
+    AUTHORIZATION = "Authorization".encode("utf-8")
 
     def __init__(self, token):
-        # type: (Text) -> None
+        # type: (str) -> None
         self.token = token
 
     def __eq__(self, other):
