@@ -1,22 +1,13 @@
 # coding: utf-8
-from __future__ import unicode_literals
-
 from random import randint
 from time import time
+from typing import Optional
+
+from requests import Request
 
-from ..compat import get_bytes
 from .base import AuthBase
 from .utils import make_portal_sso_token
 
-try:
-    from typing import TYPE_CHECKING
-
-    if TYPE_CHECKING:
-        from typing import Optional, Text
-        from requests import Request
-except ImportError:
-    pass
-
 
 class PortalSSOAuth(AuthBase):
     """Attaches required HTTP headers for SSO with Portals.
@@ -25,13 +16,13 @@ class PortalSSOAuth(AuthBase):
 
     __slots__ = ("digest_algorithm", "secret", "username")
 
-    NX_USER = get_bytes("NX_USER")
-    NX_TOKEN = get_bytes("NX_TOKEN")
-    NX_RD = get_bytes("NX_RD")
-    NX_TS = get_bytes("NX_TS")
+    NX_USER = "NX_USER".encode("utf-8")
+    NX_TOKEN = "NX_TOKEN".encode("utf-8")
+    NX_RD = "NX_RD".encode("utf-8")
+    NX_TS = "NX_TS".encode("utf-8")
 
     def __init__(self, username, secret, digest_algorithm="md5"):
-        # type: (Text, Text, Optional[Text]) -> None
+        # type: (str, str, Optional[str]) -> None
         self.username = username
         self.secret = secret
         self.digest_algorithm = digest_algorithm.lower()
