@@ -1,28 +1,18 @@
 # coding: utf-8
-from __future__ import unicode_literals
-
+from _hashlib import HASH
 import hashlib
 import logging
 import mimetypes
 import sys
 from distutils.version import StrictVersion
+from functools import lru_cache
+from typing import Any, Dict, List, Optional, Tuple, Union
+
+from requests import Response
 
 from . import constants
-from .compat import lru_cache
 from .constants import UP_AMAZON_S3
 
-try:
-    from typing import TYPE_CHECKING
-
-    if TYPE_CHECKING:
-        from requests import Response
-        from _hashlib import HASH
-        from typing import Any, Dict, List, Optional, Text, Tuple, Union
-
-        from requests import Response  # noqa
-except ImportError:
-    pass
-
 
 logger = logging.getLogger(__name__)
 WIN32_PATCHED_MIME_TYPES = {
@@ -39,7 +29,7 @@ WIN32_PATCHED_MIME_TYPES = {
 
 
 def chunk_partition(file_size, desired_chunk_size, handler=""):
-    # type: (int, int, Optional[Text]) -> Tuple[int, int]
+    # type: (int, int, Optional[str]) -> Tuple[int, int]
     """Determine the chunk count and chunk size from
     given *file_size* and *desired_chunk_size*.
 
@@ -76,7 +66,7 @@ def chunk_partition(file_size, desired_chunk_size, handler=""):
 
 
 def cmp(a, b):
-    # type: (Union[None, Text, StrictVersion], Union[None, Text, StrictVersion]) -> int
+    # type: (Union[None, str, StrictVersion], Union[None, str, StrictVersion]) -> int
     """
     cmp() does not exist anymore in Python 3.
     Note: this function cannot be decorated with lru_cache() because when
@@ -93,7 +83,7 @@ def cmp(a, b):
 
 
 def get_digest_algorithm(digest):
-    # type: (Text) -> Optional[Text]
+    # type: (str) -> Optional[str]
 
     # Available algorithms
     digesters = {
@@ -115,7 +105,7 @@ def get_digest_algorithm(digest):
 
 
 def get_digest_hash(algorithm):
-    # type: (Text) -> Optional[HASH]
+    # type: (str) -> Optional[HASH]
 
     # Retrieve the hashlib function for the given digest, None if not found
     func = getattr(hashlib, algorithm, None)
@@ -124,7 +114,7 @@ def get_digest_hash(algorithm):
 
 
 def get_digester(digest):
-    # type: (Text) -> Optional[HASH]
+    # type: (str) -> Optional[HASH]
     """
     Get the digester corresponding to the given hash.
 
@@ -145,7 +135,7 @@ def get_digester(digest):
 
 
 def guess_mimetype(filename):
-    # type: (Text) -> Text
+    # type: (str) -> str
     """ Guess the mimetype of a given file. """
     mime_type, _ = mimetypes.guess_type(filename)
     if mime_type:
@@ -159,7 +149,7 @@ def guess_mimetype(filename):
 
 
 def get_response_content(response, limit_size):
-    # type: (Response, int) -> Text
+    # type: (Response, int) -> str
     """Log a server response."""
     # Do not use response.text as it will load the chardet module and its
     # heavy encoding detection mecanism. The server will only return UTF-8.
@@ -169,22 +159,20 @@ def get_response_content(response, limit_size):
         content_size = len(content)
         if content_size > limit_size:
             content = content[:limit_size]
-            content = "{} [...] ({:,} bytes skipped)".format(
-                content, content_size - limit_size
-            )
+            content = f"{content} [...] ({content_size - limit_size:,} bytes skipped)"
     except (MemoryError, OverflowError):
         # OverflowError: join() result is too long (in requests.models.content)
         # Still check for memory errors, this should never happen; or else,
         # it should be painless.
         headers = response.headers
         content_size = int(headers.get("content-length", 0))
-        content = "<no enough memory ({:,} bytes)>".format(content_size)
+        content = "<no enough memory ({content_size:,} bytes)>"
 
     return content
 
 
 def json_helper(obj):
-    # type: (Any) -> Dict[Text, Any]
+    # type: (Any) -> Dict[str, Any]
     return obj.to_json()
 
 
@@ -201,14 +189,11 @@ def log_chunk_details(chunk_count, chunk_size, uploaded_chunks, blob_size):
 
     uploaded_chunks_count = len(uploaded_chunks)
     uploaded_data_length = min(blob_size, chunk_size * uploaded_chunks_count)
-    msg = (
-        "Computed chunks count is {:,d}"
-        "; chunks size is {:,d} bytes"
-        "; uploaded chunks count is {:,d}"
-        " => uploaded data so far is {:,d} bytes."
-    )
-    details = msg.format(
-        chunk_count, chunk_size, uploaded_chunks_count, uploaded_data_length
+    details = (
+        f"Computed chunks count is {chunk_count:,}"
+        f"; chunks size is {chunk_size:,} bytes"
+        f"; uploaded chunks count is {uploaded_chunks_count:,}"
+        f" => uploaded data so far is {uploaded_data_length:,} bytes."
     )
     logger.debug(details)
 
@@ -251,7 +236,7 @@ def log_response(response, *args, **kwargs):
         # The Content-Type is a binary one, but it does not contain JSON data
         # Skipped binary types are everything but "text/xxx":
         #   https://www.iana.org/assignments/media-types/media-types.xhtml
-        content = "<binary data ({:,} bytes)>".format(content_size)
+        content = f"<binary data ({content_size:,} bytes)>"
     elif chunked or content_size > 0:
         # At this point, we should only have text data not bigger than *limit_size*.
         content = get_response_content(response, constants.LOG_LIMIT_SIZE)
@@ -262,16 +247,15 @@ def log_response(response, *args, **kwargs):
         content = "<no content>"
 
     logger.debug(
-        "Response from {!r} [{}]: {!r} with headers {!r} and cookies {!r}".format(
-            response.url, response.status_code, content, headers, response.cookies
-        )
+        f"Response from {response.url!r} [{response.status_code}]: {content!r}"
+        f" with headers {headers!r} and cookies {response.cookies!r}"
     )
     return response
 
 
 @lru_cache(maxsize=128)
 def version_compare(x, y):
-    # type: (Text, Text) -> int
+    # type: (str, str) -> int
     """
     Compare version numbers using the usual x.y.z pattern.
     For instance, will result in:
@@ -351,7 +335,7 @@ def version_compare(x, y):
 
 @lru_cache(maxsize=128)
 def version_compare_client(x, y):
-    # type: (Text, Text) -> int
+    # type: (str, str) -> int
     """ Try to compare SemVer and fallback to version_compare on error. """
 
     # Ignore date based versions, they will be treated as normal versions
@@ -368,13 +352,13 @@ def version_compare_client(x, y):
 
 @lru_cache(maxsize=128)
 def version_le(x, y):
-    # type: (Text, Text) -> bool
+    # type: (str, str) -> bool
     """ x <= y """
     return version_compare_client(x, y) <= 0
 
 
 @lru_cache(maxsize=128)
 def version_lt(x, y):
-    # type: (Text, Text) -> bool
+    # type: (str, str) -> bool
     """ x < y """
     return version_compare_client(x, y) < 0
